Module binary

Module binary 

Chapter 3. Binary Encoding.

Structs

CounterMask
Counter index mask structure in SBI function calls for the PMU extension 11.
HartIds
Iterator structure for HartMask.
HartMask
Hart mask structure in SBI function calls.
Physical
Physical slice wrapper with type annotation.
SbiRet
SBI functions return type.
SharedPtr
Shared memory physical address raw pointer with type annotation.
TriggerMask
Debug trigger mask structure for the DBTR extension 19.

Enums

Error
RISC-V SBI error in enumeration.
MaskError
Error of mask modification.

Constants

RET_ERR_ALREADY_AVAILABLE
Error for resource already available.
RET_ERR_ALREADY_STARTED
Error for resource already started.
RET_ERR_ALREADY_STOPPED
Error for resource already stopped.
RET_ERR_BAD_RANGE
Error for bad or invalid range.
RET_ERR_DENIED
Error for denied.
RET_ERR_DENIED_LOCKED
Error for denied or not allowed due to lock status.
RET_ERR_FAILED
Error for SBI call failed for unknown reasons.
RET_ERR_INVALID_ADDRESS
Error for invalid address.
RET_ERR_INVALID_PARAM
Error for invalid parameter.
RET_ERR_INVALID_STATE
Error for invalid state.
RET_ERR_IO
Error for input or output error.
RET_ERR_NOT_SUPPORTED
Error for target operation not supported.
RET_ERR_NO_SHMEM
Error for shared memory not available.
RET_ERR_TIMEOUT
Error for failed due to timeout.
RET_SUCCESS
SBI success state return value.

Traits

SbiRegister
Data type of register that can be passed to the RISC-V SBI ABI.