TriggerMask

Struct TriggerMask 

pub struct TriggerMask<T = usize> { /* private fields */ }
Debug trigger mask structure for the DBTR extension 19.

Implementations

Source

impl<T: SbiRegister> TriggerMask<T>

pub const fn from_mask_base(trig_idx_mask: T, trig_idx_base: T) -> Self

Construct a TriggerMask from mask value and base counter index.

The trig_idx_base specifies the starting trigger index, while the trig_idx_mask is a bitmask indicating which triggers, relative to the base, are to be operated.

pub const fn into_inner(self) -> (T, T)

Returns mask and base parameters from the TriggerMask.