Chapter 3. Binary Encoding.
Structs
- Counter
Mask - Counter index mask structure in SBI function calls for the
PMUextension 11. - HartIds
- Iterator structure for
HartMask. - Hart
Mask - Hart mask structure in SBI function calls.
- Physical
- Physical slice wrapper with type annotation.
- SbiRet
- SBI functions return type.
- Shared
Ptr - Shared memory physical address raw pointer with type annotation.
- Trigger
Mask - Debug trigger mask structure for the
DBTRextension 19.
Enums
Constants
- RET_
ERR_ ALREADY_ AVAILABLE - Error for resource already available.
- RET_
ERR_ ALREADY_ STARTED - Error for resource already started.
- RET_
ERR_ ALREADY_ STOPPED - Error for resource already stopped.
- RET_
ERR_ BAD_ RANGE - Error for bad or invalid range.
- RET_
ERR_ DENIED - Error for denied.
- RET_
ERR_ DENIED_ LOCKED - Error for denied or not allowed due to lock status.
- RET_
ERR_ FAILED - Error for SBI call failed for unknown reasons.
- RET_
ERR_ INVALID_ ADDRESS - Error for invalid address.
- RET_
ERR_ INVALID_ PARAM - Error for invalid parameter.
- RET_
ERR_ INVALID_ STATE - Error for invalid state.
- RET_
ERR_ IO - Error for input or output error.
- RET_
ERR_ NOT_ SUPPORTED - Error for target operation not supported.
- RET_
ERR_ NO_ SHMEM - Error for shared memory not available.
- RET_
ERR_ TIMEOUT - Error for failed due to timeout.
- RET_
SUCCESS - SBI success state return value.
Traits
- SbiRegister
- Data type of register that can be passed to the RISC-V SBI ABI.